@@ -1,19 +1,19 @@
 // Take a look at the license at the top of the repository in the LICENSE file.
 
 #![doc = include_str!("../README.md")]
-#![cfg_attr(feature = "dox", feature(doc_cfg))]
+#![allow(deprecated)]
+#![cfg_attr(docsrs, feature(doc_cfg))]
 
 pub use ffi;
 pub use gdk;
 pub use gio;
 pub use glib;
-pub use wayland_client;
-
-#[cfg(any(feature = "v4_4", feature = "dox"))]
+#[cfg(all(feature = "v4_4", feature = "egl"))]
+#[cfg_attr(docsrs, doc(cfg(all(feature = "v4_4", feature = "egl"))))]
 pub use khronos_egl;
-
-#[cfg(any(feature = "v4_4", feature = "dox"))]
-pub use xkb;
+#[cfg(feature = "wayland_crate")]
+#[cfg_attr(docsrs, doc(cfg(feature = "wayland_crate")))]
+pub use wayland_client;
 
 mod auto;
 
@@ -25,3 +25,4 @@ mod wayland_display;
 mod wayland_monitor;
 mod wayland_seat;
 mod wayland_surface;
+mod wayland_toplevel;
